@@ -1,13 +1,13 @@
 import copy
 import sys
+import time
+from logging import Logger, getLogger
 from typing import Dict, Optional
 
-import pandas as pd
-import wandb
-from omegaconf import OmegaConf
-from yaml import dump
-
 from fseval.types import Callback
+from omegaconf import OmegaConf
+
+import wandb
 
 
 # Recursive dictionary merge
@@ -42,6 +42,19 @@ class WandbCallback(Callback):
         kwargs = OmegaConf.create(kwargs)
         kwargs = OmegaConf.to_container(kwargs)
 
+        # whether to log metrics. in the case of a resumation run, a user might probably
+        # not want to log metrics, but just update the tables instead.
+        kwargs.setdefault("log_metrics", True)
+        self.log_metrics = kwargs.pop("log_metrics")
+
+        if not self.log_metrics:
+            logger: Logger = getLogger(__name__)
+            logger.warn(
+                "logging metrics was disabled by user: "
+                + "logging only summary and tables to wandb."
+            )
+
+        # the `kwargs` are passed to `wandb.init`
         self.callback_config = kwargs
 
     def on_begin(self):
@@ -64,8 +77,13 @@ class WandbCallback(Callback):
         dict_merge(wandb.config, config)
 
     def on_metrics(self, metrics):
-        if isinstance(metrics, Dict):
+        if not self.log_metrics:
+            return
+        elif isinstance(metrics, Dict):
             wandb.log(metrics)
+
+            # take wandb rate limiting into account: sleep to prevent getting limited
+            time.sleep(1.5)
         else:
             raise ValueError(f"Incorrect metric type passed: {type(metrics)}")
 
