@@ -1,16 +1,12 @@
 import re
 from dataclasses import dataclass
-from itertools import chain
 from logging import Logger, getLogger
 from typing import Any, Dict, Optional, Tuple, Union
 
 import numpy as np
-from hydra.core.config_store import ConfigStore
+from fseval.types import Task, TerminalColor
 from hydra.utils import instantiate
-from omegaconf import II, MISSING, DictConfig, OmegaConf
-from sklearn.preprocessing import minmax_scale
-
-from fseval.types import AbstractAdapter, IncompatibilityError, Task, TerminalColor
+from omegaconf import MISSING, OmegaConf
 
 
 @dataclass
@@ -60,6 +56,7 @@ class DatasetConfig:
 
 @dataclass
 class Dataset:
+    name: str
     X: np.ndarray
     y: np.ndarray
     n: int
@@ -167,7 +164,7 @@ class DatasetLoader(DatasetConfig):
         multioutput = y.ndim > 1
         feature_importances = self.get_feature_importances(X, n, p)
 
-        dataset = Dataset(X, y, n, p, multioutput, feature_importances)
+        dataset = Dataset(self.name, X, y, n, p, multioutput, feature_importances)
         self.logger.info(
             f"loaded dataset {TerminalColor.yellow(self.name)} "
             + TerminalColor.green("✓")
