@@ -1,109 +1,54 @@
-import time
 from dataclasses import dataclass
 from logging import Logger, getLogger
-from typing import cast
+from typing import List, cast
 
 import numpy as np
 import pandas as pd
 from fseval.callbacks import WandbCallback
-from fseval.pipeline.cv import CrossValidator
-from fseval.pipeline.dataset import Dataset, DatasetConfig
-from fseval.pipeline.estimator import Estimator, TaskedEstimatorConfig
-from fseval.pipeline.resample import Resample, ResampleConfig
-from fseval.types import AbstractEstimator, Callback, IncompatibilityError, Task
-from hydra.core.config_store import ConfigStore
-from hydra.utils import instantiate
-from omegaconf import II, MISSING
-from sklearn.base import BaseEstimator, clone
-from sklearn.ensemble import VotingClassifier, VotingRegressor
-from sklearn.ensemble._base import _BaseHeterogeneousEnsemble
-from sklearn.feature_selection import SelectFromModel, SelectKBest
-from sklearn.metrics import log_loss, r2_score
-from sklearn.preprocessing import MinMaxScaler
-from sklearn.utils.metaestimators import _BaseComposition
+from fseval.pipeline.estimator import Estimator
+from omegaconf import MISSING
+from sklearn.base import clone
 from tqdm import tqdm
 
 from .._experiment import Experiment
-from .._pipeline import Pipeline
 from ._config import RankAndValidatePipeline
 from ._ranking_validator import RankingValidator
-
-
-@dataclass
-class SubsetValidator(Experiment, RankAndValidatePipeline):
-    """Validates one feature subset using a given validation estimator. i.e. it first
-    performs feature selection using the ranking made available in the fitted ranker,
-    `self.ranker`, and then fits/scores an estimator on that subset."""
-
-    bootstrap_state: int = MISSING
-    n_features_to_select: int = MISSING
-
-    def __post_init__(self):
-        if not self.validator.estimates_target:
-            raise IncompatibilityError(
-                f"{self.validator.name} does not predict targets: "
-                + "this estimator cannot be used as a validator."
-            )
-
-        super(SubsetValidator, self).__post_init__()
-
-    def _get_estimator(self):
-        yield self.validator
-
-    def _logger(self, estimator):
-        return lambda text: None
-
-    def _get_feature_importances(self, estimator: Estimator):
-        if estimator.estimates_feature_importances:
-            return estimator.feature_importances_
-        elif estimator.estimates_feature_ranking:
-            return estimator.feature_ranking_
-        else:
-            raise ValueError(
-                f"could not resolve feature_importances vector on {estimator.name}."
-            )
-
-    def _prepare_data(self, X, y):
-        # select n features: perform feature selection
-        selector = SelectFromModel(
-            estimator=self.ranker,
-            threshold=-np.inf,
-            max_features=self.n_features_to_select,
-            importance_getter=self._get_feature_importances,
-            prefit=True,
-        )
-        X = selector.transform(X)
-        return X, y
-
-    def fit(self, X, y):
-        override = f"bootstrap_state={self.bootstrap_state}"
-        override += f",n_features_to_select={self.n_features_to_select}"
-        filename = f"validation[{override}].pickle"
-        restored = self.storage_provider.restore_pickle(filename)
-
-        if restored:
-            self.validator.estimator = restored
-            self.logger.info("restored validator from storage provider ✓")
-        else:
-            super(SubsetValidator, self).fit(X, y)
-            self.storage_provider.save_pickle(filename, self.validator.estimator)
-
-    def score(self, X, y):
-        score = super(SubsetValidator, self).score(X, y)
-        score["n_features_to_select"] = self.n_features_to_select
-        score["fit_time"] = self.validator.fit_time_
-        return score
+from ._subset_validator import SubsetValidator
 
 
 @dataclass
 class DatasetValidator(Experiment, RankAndValidatePipeline):
     """Validates an entire dataset, given a fitted ranker and its feature ranking. Fits
-    at most 50 feature subsets, at each step incrementally including more top-features."""
+    at most `p` feature subsets, at each step incrementally including more top-features."""
 
     bootstrap_state: int = MISSING
 
+    def _get_all_features_to_select(self, n: int, p: int) -> List[int]:
+        """parse all features to select from config"""
+        # set using `exec`
+        localz = locals()
+        exec(
+            f"all_features_to_select = {self.all_features_to_select}",
+            globals(),
+            localz,
+        )
+        all_features_to_select = localz["all_features_to_select"]
+        all_features_to_select = cast(List[int], all_features_to_select)
+        all_features_to_select = list(all_features_to_select)
+
+        assert (
+            all_features_to_select
+        ), f"Incorrect `all_features_to_select` string: {self.all_features_to_select}"
+
+        return all_features_to_select
+
     def _get_estimator(self):
-        for n_features_to_select in np.arange(1, min(50, self.dataset.p) + 1):
+        all_features_to_select = self._get_all_features_to_select(
+            self.dataset.n, self.dataset.p
+        )
+
+        # validate all subsets
+        for n_features_to_select in all_features_to_select:
             config = self._get_config()
             validator = config.pop("validator")
 
@@ -205,22 +150,12 @@ class BootstrappedRankAndValidate(Experiment, RankAndValidatePipeline):
 
         ranking_scores = scores[scores["group"] == "ranking"].dropna(axis=1)
         ranking_scores = ranking_scores.drop(columns=["group"])
+        ranking_scores = ranking_scores.set_index("bootstrap_state")
         validation_scores = scores[scores["group"] == "validation"].dropna(axis=1)
         validation_scores = validation_scores.drop(columns=["group"])
 
-        wandb_callback = getattr(self.callbacks, "wandb", False)
-        if wandb_callback:
-            wandb_callback = cast(WandbCallback, wandb_callback)
-
-            # upload ranking scores
-            wandb_callback.upload_table(ranking_scores, "ranking_scores")
-
-            # upload validation scores
-            wandb_callback.upload_table(validation_scores, "validation_scores")
-
         ##### Ranking scores - aggregation
         agg_ranking_scores = ranking_scores.agg(["mean", "std", "var", "min", "max"])
-        agg_ranking_scores = agg_ranking_scores.drop(columns=["bootstrap_state"])
         # print scores
         self.logger.info(f"{self.ranker.name} ranking scores:")
         print(agg_ranking_scores)
@@ -244,26 +179,51 @@ class BootstrappedRankAndValidate(Experiment, RankAndValidatePipeline):
             agg_feature_scores_dict = agg_feature_scores.to_dict()
             agg_feature_scores_dict["n_features_to_select"] = int(n_features_to_select)
             self.callbacks.on_metrics(dict(validator=agg_feature_scores_dict))
-
-            # take wandb rate limiting into account: sleep to prevent getting limited
-            time.sleep(1.5 if wandb_callback else 0)
         # print scores
         print()
         self.logger.info(f"{self.validator.name} validation scores:")
         agg_val_scores = val_scores_per_feature.mean().drop(columns=["bootstrap_state"])
         print(agg_val_scores)
 
-        # Summary
-        summary = dict(best={})
-        if "r2_score" in ranking_scores.columns:
-            # best ranker
-            best_ranker_index = ranking_scores["r2_score"].argmax()
-            best_ranker = ranking_scores.iloc[best_ranker_index]
-            summary["best"]["ranker"] = best_ranker.to_dict()
+        ##### Summary
+        best = {}
         # best validator
         all_agg_val_scores = agg_val_scores.reset_index()
-        best_subset_index = all_agg_val_scores["score"].argmax()
-        best_subset = all_agg_val_scores.iloc[best_subset_index]
-        summary["best"]["validator"] = best_subset.to_dict()
+        best_subset_index = validation_scores["score"].argmax()
+        best_subset = validation_scores.iloc[best_subset_index]
+        best["validator"] = best_subset.to_dict()
+        # best accompanying ranking
+        best_subset_bootstrap_state = best_subset["bootstrap_state"]
+        best_ranker = ranking_scores.loc[best_subset_bootstrap_state]
+        best["ranker"] = best_ranker.to_dict()
+        # summary
+        summary = dict(best=best)
+
+        ##### Upload tables
+        wandb_callback = getattr(self.callbacks, "wandb", False)
+        if wandb_callback:
+            wandb_callback = cast(WandbCallback, wandb_callback)
+
+            ### upload summary as table: meta data and best scores
+            # metadata
+            metadata = dict()
+            metadata["ranker.name"] = self.ranker.name
+            metadata["validator.name"] = self.validator.name
+            metadata["dataset.name"] = self.dataset.name
+            metadata_df = pd.DataFrame([metadata])
+            # best scores
+            best_subset_prefixed = best_subset.add_prefix("validator.")
+            best_ranker_prefixed = best_ranker.add_prefix("ranker.")
+            best_scores = pd.concat([best_subset_prefixed, best_ranker_prefixed])
+            best_scores_df = pd.DataFrame([best_scores])
+            # upload tabular summary
+            tabular_summary = best_scores_df.assign(**metadata_df)
+            wandb_callback.upload_table(tabular_summary, "tabular_summary")
+
+            ### upload ranking scores
+            wandb_callback.upload_table(ranking_scores.reset_index(), "ranking_scores")
+
+            ### upload validation scores
+            wandb_callback.upload_table(validation_scores, "validation_scores")
 
         return summary
