@@ -1,28 +1,10 @@
 import logging
 from dataclasses import dataclass
 
-import numpy as np
-import pandas as pd
-from hydra.core.config_store import ConfigStore
-from hydra.utils import instantiate
-from omegaconf import II, MISSING
-from sklearn.base import BaseEstimator, clone
-from sklearn.ensemble import VotingClassifier, VotingRegressor
-from sklearn.ensemble._base import _BaseHeterogeneousEnsemble
-from sklearn.feature_selection import SelectFromModel, SelectKBest
-from sklearn.metrics import log_loss, r2_score
-from sklearn.preprocessing import MinMaxScaler
-from sklearn.utils import _print_elapsed_time
-from sklearn.utils.metaestimators import _BaseComposition
-from tqdm import tqdm
-
-from fseval.pipeline.cv import CrossValidator
-from fseval.pipeline.dataset import Dataset, DatasetConfig
 from fseval.pipeline.estimator import Estimator, TaskedEstimatorConfig
 from fseval.pipeline.resample import Resample, ResampleConfig
-from fseval.types import AbstractEstimator, Callback, Task
+from omegaconf import MISSING
 
-from .._experiment import Experiment
 from .._pipeline import Pipeline
 
 logger = logging.getLogger(__name__)
@@ -38,6 +20,7 @@ class RankAndValidateConfig:
     ranker: TaskedEstimatorConfig = MISSING
     validator: TaskedEstimatorConfig = MISSING
     n_bootstraps: int = MISSING
+    all_features_to_select: str = MISSING
 
 
 @dataclass
@@ -50,6 +33,7 @@ class RankAndValidatePipeline(Pipeline):
     ranker: Estimator = MISSING
     validator: Estimator = MISSING
     n_bootstraps: int = MISSING
+    all_features_to_select: str = MISSING
 
     def _get_config(self):
         return {
